@@ -6,6 +6,9 @@
 ;#  as specified in the README file that comes with the distribution.
 ;#
 ;# $Log: Lock.pm,v $
+;# Revision 0.2.1.1  2000/01/04 21:16:28  ram
+;# patch1: track where lock was issued in the code
+;#
 ;# Revision 0.2  1999/12/07 20:51:04  ram
 ;# Baseline for 0.2 release.
 ;#
@@ -27,18 +30,24 @@ package LockFile::Lock;
 # Attributes:
 #
 #	scheme		the LockFile::* object that created the lock
+#	filename	where lock was taken
+#	line		line in filename where lock was taken
 #
 sub _lock_init {
 	my $self = shift;
-	my ($scheme) = @_;
+	my ($scheme, $filename, $line) = @_;
 	$self->{'scheme'} = $scheme;
+	$self->{'filename'} = $filename;
+	$self->{'line'} = $line;
 }
 
 #
 # Common attribute access
 #
 
-sub scheme	{ $_[0]->{'scheme'} }
+sub scheme		{ $_[0]->{'scheme'} }
+sub filename	{ $_[0]->{'filename'} }
+sub line		{ $_[0]->{'line'} }
 
 #
 # ->release
@@ -50,5 +59,15 @@ sub release {
 	return $self->scheme->release($self);
 }
 
+#
+# ->where
+#
+# Returns '"filename", line #' where lock was taken.
+#
+sub where {
+	my $self = shift;
+	return sprintf '"%s", line %d', $self->filename, $self->line;
+}
+
 1;
 
